package
Version:
v0.0.0-...-24b3f9a
Opens a new window with list of versions in this module.
Published: Aug 8, 2024
License: MIT
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
MessageKindMessageCreated = "message_created"
)
type Message struct {
Kind string `json:"kind"`
Value any `json:"value"`
RoomID string `json:"-"`
}
type MessageMessageCreated struct {
ID string
Message string
}
Source Files
¶
Directories
¶
store
|
|
|
|
|
Click to show internal directories.
Click to hide internal directories.